## Ansættelseskontrakt

Mellem undertegnede

<company-name>Nordic IT Solutions ApS</company-name>  
Nørregade 14, 2. th., 4895 Errindlev  
CVR-nr.: 37546712  
(herefter 'virksomheden')

og

Martin Jørgensen  
Holmbladsgade 42, 4. tv., 4420 Regstrup  
(herefter 'medarbejderen')

indgås følgende aftale:

<start-date>
## [SECTION-IDX]. Tiltrædelse

Medarbejderen tiltræder stillingen med virkning fra den 1. august 2024.
</start-date>

<location>
## [SECTION-IDX]. Arbejdssted

Medarbejderens primære arbejdssted er:  
Nørregade 14, 2. th., 8732 Hovedgård.
</location>

<title>
## [SECTION-IDX]. Stillingsbetegnelse

Medarbejderen er ansat som Fullstack udvikler.
</title>

## [SECTION-IDX]. Arbejdsopgaver

Opgaverne består primært af:

- Udvikling og vedligeholdelse af webapplikationer  
- Deltagelse i SCRUM-møder  
- Fejlsøgning  
- Dokumentation  
- Løbende optimering og integration af nye teknologier

Arbejdets omfang og karakter kan løbende tilpasses virksomhedens aktuelle behov.

<trial-period>
Da der ikke er aftalt en prøvetid, er ansættelsesforholdet ikke omfattet af prøvetid. Opsigelsesvarsel fremgår af særskilt punkt.
</trial-period>

<salary>
## [SECTION-IDX]. Løn

Den årlige løn udgør kr. 624.000 brutto (før skat, pension og lovpligtige bidrag), svarende til kr. 52.000 brutto pr. måned. Lønnen udbetales månedsvis bagud til medarbejderens anviste konto den sidste bankdag i måneden.

Lønnen reguleres én gang årligt ved lønforhandling.
</salary>

<pension>
## [SECTION-IDX]. Pension

Der oprettes pensionsordning i PFA Pension. Virksomheden indbetaler 8% og medarbejderen 4% af alle faste løndele som pensionsbidrag til ordningen.
</pension>

<social-security>
## [SECTION-IDX]. Sociale sikringsbidrag

Virksomheden indbetaler samtlige lovpligtige sociale sikringsbidrag i henhold til gældende dansk lovgivning, herunder ATP og øvrige relevante bidrag.
</social-security>

<work-time>
## [SECTION-IDX]. Arbejdstid

Den gennemsnitlige, ugentlige arbejdstid udgør 37 timer, ekskl. frokost. Arbejdstiden placeres som udgangspunkt inden for virksomhedens normale åbningstid efter nærmere aftale.  

Den aftalte løn indeholder kompensation for eventuelt merarbejde, hvorfor der ikke ydes særskilt betaling eller afspadsering herfor, medmindre andet aftales skriftligt.
</work-time>

<holiday>
## [SECTION-IDX]. Ferie

Ferie ydes i henhold til gældende ferielov, herunder 5 ugers ferie med løn. Særligt ferietillæg udbetales med 2,48% i henhold til lovgivningen.

Juleaftensdag og nytårsaftensdag er fridage med løn.
</holiday>

<extra-holiday>
## [SECTION-IDX]. Feriefridage

Udover ferie i henhold til ferieloven, har medarbejderen ret til 5 ekstra feriefridage (6. ferieuge) pr. ferieår.  
Ubenyttede feriefridage kan enten overføres eller udbetales ved medarbejderens ønske eller i forbindelse med fratræden.
</extra-holiday>

<training>
## [SECTION-IDX]. Efteruddannelse

Medarbejderen har ret til at deltage i relevant efteruddannelse og kurser i det omfang, det er foreneligt med virksomhedens behov og gældende regler i overenskomsten. Behov drøftes løbende.
</training>

<illness>
## [SECTION-IDX]. Sygdom

Ved sygdom skal besked gives til nærmeste leder hurtigst muligt. Ved fravær ud over 3 dage kan virksomheden forlange dokumentation for sygdommen ved lægeerklæring, betalt af virksomheden.

Medarbejderen har ret til fuld sædvanlig løn under sygdom.
</illness>

<parental-leave>
## [SECTION-IDX]. Graviditet, barsel, adoption og forældreorlov

Ved graviditet, fødsel og adoption følger retten til orlov de til enhver tid gældende regler i barselloven.  
Det præciseres:

- Mor har ret til 4 ugers orlov med fuld løn før forventet fødsel og 14 uger med fuld løn efter fødslen.
- Far/medmor har ret til 2 ugers lønnet orlov umiddelbart efter fødslen.
- Ved adoption ydes tilsvarende lønret med udgangspunkt i gældende lovgivning.

Herudover har medarbejderen ret til frihed i 5 dage årligt med løn ved barns sygdom, medmindre anden ordning etableres efter overenskomsten.
</parental-leave>

<termination>
## [SECTION-IDX]. Opsigelse

Begge parter kan opsige ansættelsesforholdet med 3 måneders varsel til måneds udgang, medmindre længere eller kortere varsel følger af funktionærloven eller kollektiv overenskomst. Opsigelsen skal ske skriftligt og være modparten i hænde senest den sidste dag i måneden.
</termination>

<collective-agreement>
## [SECTION-IDX]. Kollektiv overenskomst

Ansættelsesforholdet er omfattet af Dansk Industri/PROSA overenskomsten, herunder dens bestemmelser om løn, arbejdstid, opsigelse, ferie, barsel og øvrige vilkår.
</collective-agreement>

## [SECTION-IDX]. Fortrolighed og loyalitet

Medarbejderen er underlagt tavshedspligt i og efter ansættelsesperioden omkring oplysninger, der må anses for forretningshemmeligheder. Videregivelse til uvedkommende må ikke finde sted, jf. lov om forretningshemmeligheder.

## [SECTION-IDX]. Retsgrundlag

Aftaleforholdet er hjemlet i dansk ret. I det omfang denne kontrakt og gældende overenskomst ikke stiller medarbejderen bedre, gælder funktionær- og ferieloven.

København, den 11.06.2024

Medarbejderen: _____________________________________

Virksomheden: _____________________________________